/* -*-c-*-
 *
 * $Id: msg.h,v 1.6 2002/01/13 14:32:23 mdw Exp $
 *
 * Display a message and get an answer
 *
 * (c) 1998 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of the mgLib GTK utilities library.
 *
 * mgLib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * mgLib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with mgLib; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */

/*----- Revision history --------------------------------------------------* 
 *
 * $Log: msg.h,v $
 * Revision 1.6  2002/01/13 14:32:23  mdw
 * Allow control over the message box title.
 *
 * Revision 1.5  2000/08/15 22:40:15  mdw
 * Change guard constants.
 *
 * Revision 1.4  1999/05/06 19:51:48  mdw
 * Reformatted the LGPL notice a little bit.
 *
 * Revision 1.3  1999/05/05 18:52:45  mdw
 * Change licensing conditions to LGPL.
 *
 * Revision 1.2  1999/04/29 20:48:13  mdw
 * Add documentation for `msg'.
 *
 * Revision 1.1  1998/12/11 09:44:21  mdw
 * Initial version.
 *
 */

#ifndef MGLIB_MSG_H
#define MGLIB_MSG_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Header files ------------------------------------------------------*/

#include <gtk/gtk.h>

/*----- Functions provided ------------------------------------------------*/

/* --- @msg@ --- *
 *
 * Arguments:	@const char *title@ = the title for the message box
 *		@const char *buttons@ = the button strings to display
 *		@const char *msg@ = the message skeleton string
 *
 * Returns:	Index of the button selected.
 *
 * Use:		Displays a message to the user in a nice dialogue box and
 *		returns the index of the button selected.
 *
 *		The @msg@ argument is a @printf@-style format string, which
 *		contains the message to actually be shown.  The @buttons@
 *		argument is a comma-separated list of buttons to be drawn,
 *		from right to left.  A button name can be preceded with `:'
 *		to indicate that it's the default, or `~' if it's the
 *		`cancel' button.  The return value is the zero-based index
 *		of the button selected.
 */

extern int msg(const char */*msg*/, const char */*buttons*/,
	       const char */*msg*/, ...);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
